containertools.get_first_element_starting_strictly_before_prolated_offset
=========================================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_strictly_before_prolated_offset.get_first_element_starting_strictly_before_prolated_offset
